[Bf-extensions-cvs] [ed161459] master: Fix typos in source comments and descriptions

Brecht Van Lommel noreply at git.blender.org
Tue Oct 1 20:13:52 CEST 2019


Commit: ed161459d14a31fd237cd1f65a7070113ae3300f
Author: Brecht Van Lommel
Date:   Tue Oct 1 20:13:26 2019 +0200
Branches: master
https://developer.blender.org/rBAed161459d14a31fd237cd1f65a7070113ae3300f

Fix typos in source comments and descriptions

Patch contributed by luzpaz.

Differential Revision: https://developer.blender.org/D5800

===================================================================

M	archipack/archipack_cutter.py
M	archipack/archipack_fence.py
M	archipack/archipack_keymaps.py
M	archipack/archipack_manipulator.py
M	archipack/archipack_material.py
M	archipack/archipack_rendering.py
M	archipack/archipack_slab.py
M	archipack/archipack_wall2.py
M	blenderkit/download.py
M	blenderkit/paths.py
M	blenderkit/search.py
M	blenderkit/ui.py
M	curve_tools/Curves.py
M	curve_tools/ShowCurveResolution.py
M	curve_tools/cad.py
M	curve_tools/curve_remove_doubles.py
M	io_scene_fbx/export_fbx_bin.py
M	io_scene_gltf2/blender/exp/gltf2_blender_gather.py
M	io_scene_gltf2/blender/exp/gltf2_blender_gather_nodes.py
M	io_scene_gltf2/blender/imp/gltf2_blender_gltf.py
M	io_scene_obj/import_obj.py
M	io_scene_x3d/import_x3d.py
M	materials_utils/__init__.py
M	materials_utils/functions.py
M	mesh_tiny_cad/README.md
M	object_boolean_tools.py
M	power_sequencer/operators/fade_add.py
M	power_sequencer/operators/mouse_trim_modal.py
M	power_sequencer/scripts/BPSProxy/bpsproxy/utils.py
M	power_sequencer/scripts/BPSRender/bpsrender/helpers.py
M	power_sequencer/scripts/BPSRender/bpsrender/setup.py
M	render_povray/__init__.py
M	render_povray/render.py

===================================================================

diff --git a/archipack/archipack_cutter.py b/archipack/archipack_cutter.py
index b75dc4cf..ec43ad19 100644
--- a/archipack/archipack_cutter.py
+++ b/archipack/archipack_cutter.py
@@ -144,7 +144,7 @@ class CutterGenerator():
             manipulators[1].prop1_name = "length"
             manipulators[1].set_pts([p0, p1, (side, 0, 0)])
 
-            # snap manipulator, dont change index !
+            # snap manipulator, don't change index !
             manipulators[2].set_pts([p0, p1, (side, 0, 0)])
             # dumb segment id
             manipulators[3].set_pts([p0, p1, (side, 0, 0)])
diff --git a/archipack/archipack_fence.py b/archipack/archipack_fence.py
index 3630e00e..2cd9e227 100644
--- a/archipack/archipack_fence.py
+++ b/archipack/archipack_fence.py
@@ -226,7 +226,7 @@ class FenceGenerator():
                 manipulators[1].prop2_name = "radius"
                 manipulators[1].set_pts([f.c.to_3d(), v0, v1])
 
-            # snap manipulator, dont change index !
+            # snap manipulator, don't change index !
             manipulators[2].set_pts([p0, p1, (1, 0, 0)])
 
         f = self.segs[-1]
@@ -450,7 +450,7 @@ class FenceGenerator():
                     f = self.segs[i]
                     if f.t_end < t_end:
                         if type(f).__name__ == 'CurvedFence':
-                            # cant end after segment
+                            # can't end after segment
                             t0 = max(0, (t_cur - f.t_start) / f.t_diff)
                             t1 = min(1, (t_end - f.t_start) / f.t_diff)
                             n_s = int(max(1, abs(f.da) * (5) / pi - 1))
@@ -471,7 +471,7 @@ class FenceGenerator():
                 f = self.segs[i]
                 # last section
                 if type(f).__name__ == 'CurvedFence':
-                    # cant start before segment
+                    # can't start before segment
                     t0 = max(0, (t_cur - f.t_start) / f.t_diff)
                     t1 = min(1, (t_end - f.t_start) / f.t_diff)
                     n_s = int(max(1, abs(f.da) * (5) / pi - 1))
diff --git a/archipack/archipack_keymaps.py b/archipack/archipack_keymaps.py
index 3292e0d7..f5b95957 100644
--- a/archipack/archipack_keymaps.py
+++ b/archipack/archipack_keymaps.py
@@ -104,7 +104,7 @@ class Keymaps:
 
     def dump_keys(self, context, filename="/tmp/keymap.txt"):
         """
-            Utility for developpers :
+            Utility for developers :
             Dump all keymaps to a file
             filename : string a file path to dump keymaps
         """
diff --git a/archipack/archipack_material.py b/archipack/archipack_material.py
index 71e41f32..27aaefab 100644
--- a/archipack/archipack_material.py
+++ b/archipack/archipack_material.py
@@ -149,7 +149,7 @@ class MatlibsManager():
         """
             Add material library to list
             only store name of lib
-            reloading here dosent make sense
+            reloading here doesn't make sense
         """
         loaded_path = self.loaded_path
 
diff --git a/archipack/archipack_rendering.py b/archipack/archipack_rendering.py
index 82ef9a18..09650ec8 100644
--- a/archipack/archipack_rendering.py
+++ b/archipack/archipack_rendering.py
@@ -102,7 +102,7 @@ class ARCHIPACK_OT_render_thumbs(Operator):
         presets_path = bpy.utils.user_resource('SCRIPTS',
                                               target_path,
                                               create=True)
-        # files from factory not found in user dosent require a recompute
+        # files from factory not found in user doesn't require a recompute
         skipfiles = []
         for f in file_list:
             # copy python/txt preset
diff --git a/archipack/archipack_slab.py b/archipack/archipack_slab.py
index 897686da..ae1d7be4 100644
--- a/archipack/archipack_slab.py
+++ b/archipack/archipack_slab.py
@@ -182,7 +182,7 @@ class SlabGenerator(CutAblePolygon, CutAbleGenerator):
                 manipulators[1].prop2_name = "radius"
                 manipulators[1].set_pts([f.c.to_3d(), v0, v1])
 
-            # snap manipulator, dont change index !
+            # snap manipulator, don't change index !
             manipulators[2].set_pts([p0, p1, (1, 0, 0)])
             # dumb segment id
             manipulators[3].set_pts([p0, p1, (1, 0, 0)])
diff --git a/archipack/archipack_wall2.py b/archipack/archipack_wall2.py
index 2e3cc241..d9a486eb 100644
--- a/archipack/archipack_wall2.py
+++ b/archipack/archipack_wall2.py
@@ -275,7 +275,7 @@ class WallGenerator():
                 manipulators[1].prop2_name = "radius"
                 manipulators[1].set_pts([wall.c.to_3d(), scale * v0, scale * v1])
 
-            # snap manipulator, dont change index !
+            # snap manipulator, don't change index !
             manipulators[2].set_pts([p0, p1, (1, 0, 0)])
 
             # dumb, segment index
@@ -436,7 +436,7 @@ def update_t_part(self, context):
             # 2 o has parent
             # 3 w has parent
             # 4 o and w share same parent already
-            # 5 o and w dosent share parent
+            # 5 o and w doesn't share parent
             link_to_parent = False
 
             # when both walls do have a reference point, we may delete one of them
@@ -1620,7 +1620,7 @@ class archipack_wall2(ArchipackObject, Manipulable, PropertyGroup):
         self.setup_childs(o, g)
         # store gl points
         self.update_childs(context, o, g)
-        # dont do anything ..
+        # don't do anything ..
         # self.manipulable_release(context)
         # self.manipulate_mode = True
         self.manipulable_setup(context)
@@ -1669,7 +1669,7 @@ class ARCHIPACK_OT_wall2_throttle_update(Operator):
     def modal(self, context, event):
         global update_timer_updating
         if event.type == 'TIMER' and not update_timer_updating:
-            # cant rely on TIMER event as another timer may run
+            # can't rely on TIMER event as another timer may run
             if time.time() - throttle_start > throttle_delay:
                 update_timer_updating = True
                 o = context.scene.objects.get(self.name.strip())
diff --git a/blenderkit/download.py b/blenderkit/download.py
index cb00341c..b3ecbeab 100644
--- a/blenderkit/download.py
+++ b/blenderkit/download.py
@@ -869,7 +869,7 @@ class BlenderkitDownloadOperator(bpy.types.Operator):
         s = bpy.context.scene
         sr = s['search results']
 
-        asset_data = sr[self.asset_index].to_dict()  # TODO CHECK ALL OCCURANCES OF PASSING BLENDER ID PROPS TO THREADS!
+        asset_data = sr[self.asset_index].to_dict()  # TODO CHECK ALL OCCURRENCES OF PASSING BLENDER ID PROPS TO THREADS!
         au = s.get('assets used')
         if au == None:
             s['assets used'] = {}
diff --git a/blenderkit/paths.py b/blenderkit/paths.py
index 3aa7aaa9..4a9a2cd6 100644
--- a/blenderkit/paths.py
+++ b/blenderkit/paths.py
@@ -164,7 +164,7 @@ def get_download_filenames(asset_data):
     file_names = []
     # fn = asset_data['file_name'].replace('blend_', '')
     if asset_data.get('url') is not None:
-        # this means asset is already in scene and we don't nedd to check
+        # this means asset is already in scene and we don't need to check
 
         fn = extract_filename_from_url(asset_data['url'])
         fn.replace('_blend', '')
diff --git a/blenderkit/search.py b/blenderkit/search.py
index 83bdb2ec..8e0c0140 100644
--- a/blenderkit/search.py
+++ b/blenderkit/search.py
@@ -122,9 +122,8 @@ def timer_update():  # TODO might get moved to handle all blenderkit stuff.
     # causing a lot of throuble literally.
     if len(search_threads) == 0 or bpy.context.scene.blenderkitUI.dragging:
         return 1
-    for thread in search_threads:  # TODO this doesn't check all processess when one gets removed, but most time only
-        # one is running anyway
-
+    for thread in search_threads:  # TODO this doesn't check all processes when one gets removed,
+                                   # but most of the time only one is running anyway
         if not thread[0].is_alive():
             print('parsing')
             search_threads.remove(thread)  #
@@ -808,7 +807,7 @@ class Searcher(threading.Thread):
         full_thbs = zip(thumb_full_filepaths, thumb_full_urls)
 
         # we save here because a missing thumbnail check is in the previous loop
-        # we can also prepend previous results. These have already thumbnails downloaded...
+        # we can also prepend previous results. These have downloaded thumbnails already...
         if params['get_next']:
             rdata['results'][0:0] = origdata['results']
 
diff --git a/blenderkit/ui.py b/blenderkit/ui.py
index e35a9298..e4eea0c1 100644
--- a/blenderkit/ui.py
+++ b/blenderkit/ui.py
@@ -271,7 +271,7 @@ def draw_ratings_bgl():
             ui_img_name = 'rating_ui.png'
         else:
             ui_img_name = 'rating_ui_empty.png'
-            text = 'Try to estimate how many hours it would take to a proffesional artist to create this asset:'
+            text = 'Try to estimate how many hours it would take for a professional artist to create this asset:'
             tx = ui.rating_x + ui.workhours_bar_x
             # draw_text_block(x=tx, y=ui.rating_y, width=80, font_size=20, line_height=15, text=text, color=colors.TEXT)
 
diff --git a/archipack/archipack_manipulator.py b/archipack/archipack_manipulator.py
index 60a05738..0eba8aba 100644
--- a/archipack/archipack_manipulator.py
+++ b/archipack/archipack_manipulator.py
@@ -263,7 +263,7 @@ class Manipulator():
 
     def exit(self):
         """
             Modal exit, DONT EVEN TRY TO OVERRIDE
         """
         if self._handle is not None:
             bpy.types.SpaceView3D.draw_handler_remove(self._handle, 'WINDOW')
@@ -2184,7 +2184,7 @@ class Manipulable():
         """
             call this in operator invoke()
             NB:
-            if override dont forget to call:
+            if override don't forget to call:
                 _manipulable_invoke(context)
 
         """
@@ -263,7 +263,7 @@ class Manipulator():
     def exit(self):
         """
-            Modal exit, DONT EVEN TRY TO OVERRIDE
+            Modal exit, DON'T EVEN TRY TO OVERRIDE
         """
         if self._handle is not None:
diff --git a/curve_tools/Curves.py b/curve_tools/Curves.py
index e2608eeb.

@@ Diff output truncated at 10240 characters. @@



More information about the Bf-extensions-cvs mailing list